v1.1.0 (2026-01-08)
-------------------------
 * Bump python versions in CI
 * Switch from poetry to uv package manager

v1.0.0 (2025-01-14)
-------------------------
 
 * Update python, dependencies and poetry 

